﻿Type=Class
Version=4.5
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
#Region Class Notes
' Custom View Class - SelectFileTextField
' @autor rwblinn.de
' @since v20161010
' @see: Comments in the text
#End Region

'Define the Class DesignerProperties which are displayed in the B4J Visual Designer
#DesignerProperty: Key:FieldValue, Displayname: Field Value, Fieldtype: String, Defaultvalue: Default, Description: Enter filename
#DesignerProperty: Key:FieldLowerCase, Displayname: Field to Lowercase, Fieldtype: Boolean, Defaultvalue: False, Description: Set text to lowercase
#DesignerProperty: Key:FieldPromptText, DisplayName: Field Prompt, FieldType: String, DefaultValue: , Description: Enter filename
#DesignerProperty: Key:FieldTooltipText, DisplayName: Field Tooltip, FieldType: String, DefaultValue: , Description: Select a file
#DesignerProperty: Key:SelectButtonTooltipText, DisplayName: Select Button Tooltip, FieldType: String, DefaultValue: Select a File, Description: Select file dialog
#DesignerProperty: Key:SelectDialogTitle, DisplayName: Select Dialog Title, FieldType: String, DefaultValue: Select a File, Description: Enter open title
#DesignerProperty: Key:SelectDialogExtensionDescription, DisplayName: Select Dialog Extension Description, FieldType: String, DefaultValue: All Files, Description: Set the extension description
#DesignerProperty: Key:SelectDialogExtensionFilter, DisplayName: Select Dialog Extension Filter, FieldType: String, DefaultValue: *.*, Description: Set an extension filter

Private Sub Class_Globals
	Private Version As String = "v20161010"
	Private fx As JFX
	Private mEventName As String 'ignore
	Private mCallBack As Object 'ignore
	' Keep own version of base and props
	Private mBase As Pane
	Private mProps As Map
	' The views added to the base pane
	Private tfField As TextField
	Private btnSelect As Button
End Sub

Public Sub Initialize (vCallback As Object, vEventName As String)
	mEventName = vEventName
	mCallBack = vCallback
End Sub

Public Sub DesignerCreateView (Base As Pane, Lbl As Label, Props As Map)
	mBase = Base
	mProps = Props

	CSSUtils.SetBorder(mBase, 0, fx.Colors.Transparent, 0)

	tfField.Initialize("tfField")
	tfField.Style = Lbl.Style
	tfField.TooltipText = mProps.Get("FieldTooltipText")
	mBase.AddNode(tfField, 0, 0, 0, 0)
	
	btnSelect.Initialize("btnSelect")
	btnSelect.TooltipText = mProps.Get("SelectButtonTooltipText")
	CSSUtils.SetBackgroundImage(btnSelect, File.DirAssets, "select.png")
	mBase.AddNode(btnSelect, 0,0,0,0) 
End Sub

Public Sub AddToParent(Parent As Pane, Left As Int, Top As Int, Width As Int, Height As Int)
	mBase.Initialize("mBase")
	mProps.Initialize
	mProps.Put("FieldLowerCase", False)
	mProps.Put("SelectDialogTitle", "")
	mProps.Put("SelectDialogExtensionFilter", $"*.*"$)
	mProps.Put("SelectDialogExtensionDescription", "All Files")
	mProps.Put("SelectOpenDialogTitle", "Select a file")

	CSSUtils.SetBorder(mBase, 0, fx.Colors.Transparent, 0)
	tfField.Initialize("tfField")
	mBase.AddNode(tfField, 0, 0, 0, 0)
	btnSelect.Initialize("btnSelect")
	CSSUtils.SetBackgroundImage(btnSelect, File.DirAssets, "select.png")
	mBase.AddNode(btnSelect, 0,0,0,0) 
	' Add the base node to the parent
	Parent.AddNode(mBase, Left, Top, Width, Height)
	' Resize
	Base_Resize (Width, Height)
End Sub

Private Sub Base_Resize (Width As Double, Height As Double)
	tfField.SetLayoutAnimated(0, 0, 0, Width - 30, Height)
	btnSelect.SetLayoutAnimated(0, Width - 30, 0, 30, Height)
End Sub

' Method: Get or set the width of the base
Public Sub SetWidth(Width As Double)
	If Width < 100 Then Width = 100
	mBase.PrefWidth = Width
End Sub

Public Sub GetWidth As Double
	Return mBase.PrefWidth
End Sub

' Method: Get or set the height of the base
Public Sub SetHeigth(Height As Double)
	If Height < 10 Then Height = 10
	mBase.PrefHeight=Height
End Sub

Public Sub GetHeigth As Double
	Return mBase.PrefHeight
End Sub

' Property: Get or set the top position of the base
Public Sub setTop(Top As Double)
	If Top < 0 Then Top = 0
	mBase.Top = Top
End Sub

Public Sub getTop As Double
	Return mBase.Top
End Sub

' Property: Get or set the left position of the base
Public Sub setLeft(Left As Double)
	If Left < 0 Then Left = 0
	mBase.Left = Left
End Sub

Public Sub getLeft  As Double
	Return mBase.Left
End Sub

' Property: Get or set the tag of the base
Public Sub setTag(Tag As String)
    mBase.Tag = Tag
End Sub

Public Sub getTag As String
    Return mBase.Tag
End Sub

' Property: Get or set the visibility of the base
Public Sub setVisible(Visible As Boolean)
   mBase.Visible = Visible
End Sub

Public Sub getVisible As Boolean
   Return mBase.Visible
End Sub

'#DesignerProperty: Key:ValueLowerCase, Displayname: Lowercase, Fieldtype: Boolean, Defaultvalue: False, Description: Select a file
Public Sub setLowerCaseOption(Value As Boolean)
	mProps.Put("FieldLowerCase", Value)
End Sub

Public Sub getLowerCaseOption As Boolean
	Return mProps.Get("FieldLowerCase")
End Sub

' Property: Get or set text of the textfield
Public Sub getText As String
	Return tfField.Text
End Sub

Public Sub setText(Value As String)
	tfField.Text = Value
End Sub

Public Sub setToolTipText(Value As String)
	tfField.TooltipText = Value
End Sub

Public Sub getToolTipText As String
	Return tfField.TooltipText
End Sub

Private Sub tfField_TextChanged (Old As String, New As String)
	If mProps.Get("FieldLowerCase") Then New = New.ToLowerCase
	tfField.Text = New
End Sub
#End Region

#Region Dialog
public Sub setSelectDialogTitle(Value As String)
	mProps.Put("SelectDialogTitle", Value)
End Sub

public Sub getSelectDialogTitle As String
	Return mProps.get("SelectDialogTitle")
End Sub

public Sub setExtensionFilter(Value As String)
	mProps.Put("SelectDialogExtensionFilter", Value)
End Sub

public Sub getExtensionFilter As String
	Return mProps.get("SelectDialogExtensionFilter")
End Sub

public Sub setExtensionDescription(Value As String)
	mProps.Put("SelectDialogExtensionDescription", Value)
End Sub

public Sub getExtensionDescription As String
	Return mProps.Get("SelectDialogExtensionDescription")
End Sub

Public Sub setButtonToolTipText(Value As String)
	btnSelect.TooltipText = Value
End Sub

Public Sub getButtonToolTipText As String
	Return btnSelect.TooltipText
End Sub

Private Sub btnSelect_Action
	Dim fc As FileChooser
	Dim fileSelected As String			'File selected. If selected full path is returned else ""
  	fc.Initialize                       'Init! Do not forget
  	fc.InitialDirectory = File.DirApp   'Set starting folder
	fc.SetExtensionFilter(getExtensionDescription, Array As String(getExtensionFilter))
  	fc.Title = mProps.Get("SelectOpenDialogTitle")
  	fileSelected = fc.ShowOpen(Null)  	'Show the dialog and select
	If fileSelected.Length > 0 Then 
		tfField.Text = fileSelected
	End If
End Sub
#End Region

Public Sub GetVersion As String
	Return Version
End Sub
